@@ -33,7 +33,7 @@ use warnings 'once';
 
 use Cwd 'abs_path';
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use App::LXC::Container::Texts;
 
@@ -112,7 +112,11 @@ sub content_audio_packages($)
     foreach (qw(pactl))
     {
 	my $exec = App::LXC::Container::Data::find_executable($_);
-	push @output, App::LXC::Container::Data::package_of($exec)  if  $exec;
+	if ($exec)
+	{
+	    my $pkg = App::LXC::Container::Data::package_of($exec);
+	    push @output, $pkg  if  $pkg;
+	}
     }
     return @output;
 }
@@ -375,7 +379,11 @@ sub content_network_packages($)
     foreach (qw(ip))
     {
 	my $exec = App::LXC::Container::Data::find_executable($_);
-	push @output, App::LXC::Container::Data::package_of($exec)  if  $exec;
+	if ($exec)
+	{
+	    my $pkg = App::LXC::Container::Data::package_of($exec);
+	    push @output, $pkg  if  $pkg;
+	}
     }
     return @output;
 }
